Rescale a secondary-axis variable into primary-axis coordinates
Source:R/utils-internal.R
dot-variable_scaler.RdUsed by the distribution plots (LCD/LRD/TRP) to overlay a frequency polygon on a bar chart with a different y-scale.
R/utils-internal.R
dot-variable_scaler.RdUsed by the distribution plots (LCD/LRD/TRP) to overlay a frequency polygon on a bar chart with a different y-scale.