Resolve the colors argument against the number of colors needed
Source:R/utils-internal.R
dot-resolve_colors.RdIf colors is NULL, the package default palette is used. If the
user supplies fewer colors than needed, a warning is issued and the
colors are recycled (instead of silently producing NA colors).